<?xml version="1.0" encoding="iso-8859-1"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<xsl:output method="html" doctype-public="-//W3C//DTD HTML 4.01//EN" omit-xml-declaration="yes" indent="yes" />

<xsl:template match="/">
  <html>
  <head>
   <link rel="stylesheet" type="text/css" href="format-html.css" />
   <link rel="stylesheet" type="text/css" href="format-html1.css" />
   <script src="script.js" type="text/javascript">
    <xsl:text disable-output-escaping="yes">&#32;</xsl:text>
   </script>
  </head>
  <body>
   <xsl:apply-templates />
   <xsl:apply-templates select="//app" mode="beforeparagraph"/>
  </body>
 </html>
</xsl:template>

<xsl:template match="teiHeader">
</xsl:template>

<xsl:template match="witList">
 <div class="witList">
  <table>
   <xsl:apply-templates />
  </table>
 </div>
</xsl:template>

<xsl:template match="witList/witness">
 <tr class="witness">
  <td class="mss">
   <xsl:apply-templates />
   <xsl:text> : </xsl:text>
  </td>
  <td class="sigil">
   <xsl:value-of select="substring-after(@sigil,'M')" />
  </td>
 </tr>
</xsl:template>

<xsl:template match="witList/witness" mode="app">
  <xsl:apply-templates />
</xsl:template>

<xsl:template match="witness/hi">
 <span style="{@rend}">
  <xsl:apply-templates />
 </span>
</xsl:template>

<xsl:template match="rdg//p">
 <xsl:text disable-output-escaping="yes">&#32; </xsl:text> 
 <xsl:apply-templates />
</xsl:template>

<xsl:template match="note[@place='right' or @place='left']//p">
 <xsl:apply-templates />
</xsl:template>

<xsl:template match="p">
 <p>
   <xsl:apply-templates />
 </p>
</xsl:template>

<xsl:template match="head">
 <h1>
   <xsl:apply-templates />
 </h1>
</xsl:template>

<xsl:template match="app" mode="beforeparagraph">
 <div class="app">
  <xsl:attribute name="id">
   <xsl:text>A</xsl:text>
   <xsl:number count="//app" level="any" />
  </xsl:attribute>
    <span class="app2">
	  <xsl:apply-templates />
    </span>
 </div>
</xsl:template>

<xsl:template match="app">
 <xsl:text disable-output-escaping="yes">&#32; </xsl:text> 
 <xsl:variable name="id">
  <xsl:number count="//app" level="any" />
 </xsl:variable>
 <xsl:variable name="params">
  <xsl:text>('</xsl:text>
  <xsl:value-of select="$id" />
  <xsl:text>','</xsl:text>
  <xsl:value-of select="substring-after(@to,'#')" />
  <xsl:text>')</xsl:text>
 </xsl:variable>
 <xsl:if test="../../body">
  <xsl:text disable-output-escaping="yes">&lt;p&gt;</xsl:text>
 </xsl:if>
 <span class="appref" id="{$id}">
	 <xsl:attribute name="onmouseover">
	  <xsl:text>appref_mouseover</xsl:text>
	  <xsl:value-of select="$params" />
	 </xsl:attribute>
	 <xsl:attribute name="onmouseout">
	  <xsl:text>appref_mouseout</xsl:text>
	  <xsl:value-of select="$params" />
	 </xsl:attribute>
	 <xsl:attribute name="onclick">
	  <xsl:text>appref_click</xsl:text>
	  <xsl:value-of select="$params" />
	 </xsl:attribute>
	 <xsl:choose>
	  <xsl:when test="rdg/witStart">
	   <xsl:text> [# </xsl:text>
	  </xsl:when>
	  <xsl:when test="rdg/witEnd">
	   <xsl:text> #] </xsl:text>
	  </xsl:when>
	  <xsl:otherwise>
	   <xsl:text>&#x2df;</xsl:text>
	  </xsl:otherwise>
	 </xsl:choose> 
 </span>
 <xsl:if test="../../body">
  <xsl:text disable-output-escaping="yes">&lt;/p&gt;</xsl:text>
 </xsl:if>
 </xsl:template>

<xsl:template match="anchor">
 <a id="{@xml:id}" class="anchor" style="visibility:hidden;">
  <xsl:text>]</xsl:text>
  <!--xsl:value-of select="@xml:id" /-->
 </a>
</xsl:template>

<xsl:template match="rdg">
  <xsl:call-template name="Witnesses">
   <xsl:with-param name="mss" select="@wit" />
   <xsl:with-param name="det" select="@xml:id" />
  </xsl:call-template>
  <xsl:text disable-output-escaping="no">&#160;: </xsl:text>
  <xsl:choose>
   <xsl:when test="witStart or witEnd">
    <xsl:apply-templates />
   </xsl:when>
   <xsl:when test="normalize-space(string(current()))=''">
    <span style="font-style:italic;">
     <xsl:text> om. </xsl:text>
    </span>
   </xsl:when>
   <xsl:otherwise> 
    <xsl:apply-templates />
   </xsl:otherwise> 
  </xsl:choose>
  <xsl:if test="following-sibling::rdg[position()=1]">
   <br />
  </xsl:if> 
</xsl:template>

<xsl:template name="Witnesses">
 <xsl:param name="mss" />
 <xsl:param name="det" />
 <span class="mss">
  <xsl:call-template name="AWitness">
   <xsl:with-param name="mss" select="concat(normalize-space($mss),' ')" />
   <xsl:with-param name="det" select="$det" />
  </xsl:call-template>
 </span>
</xsl:template>

<xsl:template name="AWitness">
 <xsl:param name="mss" />
 <xsl:param name="det" />
 <xsl:variable name="ms" select="normalize-space(substring-before($mss,' '))" />
 <xsl:if test="$ms!=''">
  <xsl:choose>
   <xsl:when test="//witList/witness[@sigil=$ms]">
    <xsl:apply-templates select="//witList/witness[@sigil=$ms]" mode="app" />
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="$ms" />
   </xsl:otherwise>
  </xsl:choose>
  <xsl:if test="$det!=''">
   <xsl:for-each select="//witDetail[@target=$det]">
    <xsl:if test="@wit=$ms">
     <xsl:text> (</xsl:text>    
     <xsl:apply-templates />
     <xsl:text>)</xsl:text>
    </xsl:if>
   </xsl:for-each>
  </xsl:if>
 </xsl:if>
 <xsl:variable name="mss1" select="normalize-space(substring-after($mss,' '))" />
 <xsl:if test="$mss1!=''">
  <xsl:text> </xsl:text>
  <xsl:call-template name="AWitness">
   <xsl:with-param name="mss" select="concat($mss1,' ')" />
  </xsl:call-template>
 </xsl:if>
</xsl:template>

<xsl:template match="witDetail">
</xsl:template>

<xsl:template match="witStart">
 <i>
  <xsl:text> inc. </xsl:text>
 </i>
</xsl:template>

<xsl:template match="witEnd">
 <i>
  <xsl:text> des. </xsl:text>
 </i>
</xsl:template>

<xsl:template match="rdg/note">
  <span class="rdg_note">
  <xsl:text> (</xsl:text> 
  <xsl:apply-templates />
  <xsl:text>) </xsl:text> 
  </span>
</xsl:template>

<xsl:template match="note[@place='right' or @place='left']">
  <span class="{@place}">
  <!--xsl:text> (</xsl:text> 
   <xsl:value-of select="@place" />
  <xsl:text>: </xsl:text--> 
  <xsl:apply-templates />
  <!--xsl:text>) </xsl:text--> 
  </span>
</xsl:template>

<xsl:template match="note[@place='foot']">
  <span class="{@class}">
  <!--xsl:text> (foot:</xsl:text--> 
  <xsl:apply-templates />
  <!--xsl:text>) </xsl:text--> 
  </span>
</xsl:template>

<xsl:template match="ref[@name='sync']">
	<a class="sync">
		<xsl:attribute name="name">
			<xsl:text>s</xsl:text>
			<xsl:number format="1" level="any" />
		</xsl:attribute>
	</a>
</xsl:template>

<xsl:template match="emph">
 <span class="emph" name="{@name}">
   <xsl:apply-templates />
 </span>
</xsl:template>

<xsl:template match="mentioned">
 <span class="mentioned">
   <xsl:apply-templates />
 </span>
</xsl:template>

<xsl:template match="mentioned//hi[@rend='b']">
</xsl:template>

<xsl:template match="hi">
 <xsl:variable name="style">
   <xsl:if test="contains(concat(@rend,' '),'i ')">
    <xsl:text>font-style:italic;</xsl:text>
   </xsl:if>
   <xsl:if test="contains(concat(@rend,' '),'b ')">
    <xsl:text>font-weight:bold;</xsl:text>
   </xsl:if>
   <xsl:if test="contains(concat(@rend,' '),'ul ')">
    <xsl:text>text-decoration:underline;</xsl:text>
   </xsl:if>
   <xsl:if test="contains(concat(@rend,' '),'strike ')">
    <xsl:text>text-decoration:line-through;</xsl:text>
   </xsl:if>
   <xsl:if test="contains(concat(@rend,' '),'caps ')">
    <xsl:text>text-transform:uppercase;</xsl:text>
   </xsl:if>
   <xsl:if test="contains(concat(@rend,' '),'sc ')">
    <xsl:text>font-variant:small-caps;</xsl:text>
   </xsl:if>
   <xsl:if test="contains(concat(@rend,' '),'sup ')">
    <xsl:text>vertical-align:super;font-size:smaller;</xsl:text>
   </xsl:if>
   <xsl:if test="contains(concat(@rend,' '),'sub ')">
    <xsl:text>vertical-align:sub;font-size:smaller;</xsl:text>
   </xsl:if>
   <xsl:if test="contains(concat(@rend,' '),'expanded ')">
    <xsl:text>letter-spacing:0.2em;</xsl:text>
   </xsl:if>
   <xsl:if test="contains(concat(@rend,' '),'rtl ')">
    <xsl:text>direction:rtl;</xsl:text>
   </xsl:if>
   <xsl:if test="contains(concat(@rend,' '),'hide ')">
    <xsl:text>display:none;</xsl:text>
   </xsl:if>
 </xsl:variable>
 <span>
   <xsl:attribute name="style">
    <xsl:value-of select="$style" />
   </xsl:attribute>
   <xsl:apply-templates />
 </span>
</xsl:template>

<xsl:template match="graphic">
	<img src="{@url}" style="width:{@width}; height:{@height}" />
</xsl:template>

<xsl:template match="binaryObject">
	<img src="data:{@mimeType};base64,{current()}"  style="width:{@width}; height:{@height}"/>
</xsl:template>

</xsl:stylesheet>

